(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8850,        280]*)
(*NotebookOutlinePosition[      9530,        303]*)
(*  CellTagsIndexPosition[      9486,        299]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Visualizing GIS Data in Color", "Subtitle"],

Cell["After the 1980 Eruption", "Subsubtitle"],

Cell[BoxData[
    \(\(SetDirectory[
        ToFileName[\(("\<FileName\>" /. 
                NotebookInformation[
                  EvaluationNotebook[]])\)[\([1]\)]]];\)\)], "Input"],

Cell["\<\
First we import the data, in this case a 256x256 array of height values\
\>", "Text"],

Cell[BoxData[
    \(\(data = Reverse[Import["\<msha.txt\>", "\<Table\>"]];\)\)], "Input"],

Cell[BoxData[
    \(Dimensions[data]\)], "Input"],

Cell["We can create a plot of the height contours in this example", "Text"],

Cell[BoxData[
    \(ListContourPlot[data]\)], "Input"],

Cell[CellGroupData[{

Cell["Applying Surface Colors", "Section"],

Cell["\<\
For a more realistic view, we can use some more advanced graphics routines to \
triangulate the data and generate a surface.  We can further add realism by \
applying more realistic light sources and surface colors.\
\>", "Text"],

Cell["First, we triagulate the data using ListPlot3D.  ", "Text"],

Cell[BoxData[
    \(\(gr = ListPlot3D[data, Mesh -> False];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Monochromatic coloring", "Subsection"],

Cell["Now, we apply the lighting and surface coloring", "Text"],

Cell[BoxData[
    \(\(finalgraph = 
        Show[Graphics3D[{SurfaceColor[RGBColor[ .8,  .6,  .4]], 
              First@Graphics3D[gr]}, 
            LightSources \[Rule] {{{1, 1, 1}, White}}, Boxed \[Rule] False, 
            BoxRatios \[Rule] {1, 1,  .4}, ImageSize \[Rule] 800, 
            Background -> Black]];\)\)], "Input"],

Cell["\<\
For more interesting colors, we can let the color vary over the surface.  \
Here, the color fades from green at the base of the mountain to white at the \
top.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Hue coloring with specularity", "Subsection"],

Cell[BoxData[
    \(cfgr = 
      ListPlot3D[data, Mesh -> False, 
        ColorFunction -> \((Hue[ .8\ #] &)\)]\)], "Input"],

Cell["\<\
Surfaces can be made shiny by using the 3-argumant form of SurfaceColor.\
\>", "Text"],

Cell[BoxData[
    \(Show[Graphics3D[cfgr] /. Hue[c_] -> SurfaceColor[Hue[c], White, 10], 
      Lighting -> True, ImageSize -> 800, 
      LightSources -> {{{1, 1, 1}, White}}, Boxed -> False, Axes -> False, 
      Background -> Black]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Advanced Color Functions", "Subsection"],

Cell["\<\
For more complicated color variations, we can treat the RGB color channels \
individually.  Here, we construct linear InterpolatingFunctions for each of \
the color channels.  The goal is to get a color variation that changes from \
green at the bottom, brown in the middle, and white at the top to simulate a \
real-world landscape.\
\>", "Text"],

Cell[BoxData[
    \(\(rchannel = 
        Interpolation[{{0, 0}, { .5,  .6}, { .75, 1}, {1, 1}}, 
          InterpolationOrder -> 1];\)\)], "Input"],

Cell[BoxData[
    \(\(gchannel = 
        Interpolation[{{0, 1}, { .5,  .4}, { .75, 1}, {1, 1}}, 
          InterpolationOrder -> 1];\)\)], "Input"],

Cell[BoxData[
    \(\(bchannel = 
        Interpolation[{{0, 0}, { .5,  .2}, { .75, 1}, {1, 1}}, 
          InterpolationOrder -> 1];\)\)], "Input"],

Cell["\<\
We can view the color responses as follows.  The colors were chosen such that \
as the normalized height varies from 0 to 1, the color channels vary so as to \
give the appropriate color blend.  \
\>", "Text"],

Cell[BoxData[
    \(Plot[{rchannel[x], gchannel[x], bchannel[x]}, {x, 0, 1}, 
      PlotRange -> {0, 1}, PlotStyle -> {Red, Green, Blue}]\)], "Input"],

Cell["\<\
Here, we apply the new color function to the surface as before.\
\>", "Text"],

Cell[BoxData[
    \(cfgr2 = 
      ListPlot3D[data, Mesh -> False, 
        ColorFunction -> \((RGBColor[rchannel[#], gchannel[#], 
                Abs[bchannel[#]]] &)\), 
        ColorFunctionScaling -> True]\)], "Input"],

Cell["As before, we convert the flat colors into lit colors.", "Text"],

Cell[BoxData[
    \(msha = 
      Show[Graphics3D[cfgr2] /. 
          RGBColor[r_, g_, b_] -> SurfaceColor[RGBColor[r, g, b]], 
        Lighting -> True, ImageSize -> 800, 
        LightSources -> {{{1, 1, 1}, White}}, Axes -> False, Boxed -> False, 
        Background -> Black]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ColorFunctions from Images", "Subsection"],

Cell["\<\
First, let's import an image that can be used to construct a surface.\
\>", "Text"],

Cell[BoxData[{
    \(\(elevationData = 
        Import["\<http://edc.usgs.gov/geodata/images/susanville.gif\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[elevationData];\)\)}], "Input"],

Cell["\<\
Now, we import an image containing the color range we want for the surface \
colors.\
\>", "Text"],

Cell[BoxData[{
    \(\(colorData = Import["\<landMass.jpg\>"];\)\), "\[IndentingNewLine]", 
    \(\(Show[colorData];\)\)}], "Input"],

Cell["\<\
Here, we extract the relevant content from the raster. and construct a color \
function.\
\>", "Text"],

Cell[BoxData[{
    \(\(colorList = colorData[\([1, 1, 1]\)];\)\), "\[IndentingNewLine]", 
    \(cf[x_] := 
      RGBColor @@ \((colorList[\([1 + 
                    Round[x\ \((Length[colorList] - 1)\)]]\)]/255)\) // 
        N\)}], "Input"],

Cell["\<\
Now, we can use ListPlot3D to plot the data and apply the color function.  \
The value of the color function is scaled by raising it to a power slightly \
higher than one for aesthetics.\
\>", "Text"],

Cell[BoxData[
    \(\(lp = 
        ListPlot3D[\ elevationData[\([1, 1]\)]\ , 
          BoxRatios \[Rule] {1, 1,  .1}, Mesh \[Rule] False, 
          ColorFunction \[Rule] \((cf[#^1.19] &)\), Boxed \[Rule] False, 
          Axes \[Rule] None];\)\)], "Input"],

Cell["Once again, we convert the flat colors to lit colors.", "Text"],

Cell[BoxData[
    \(myout = 
      Show[Graphics3D[lp] /. 
          RGBColor[r_, g_, b_] \[Rule] SurfaceColor[RGBColor[r, g, b]], 
        BoxRatios \[Rule] {1, 1,  .1}, 
        LightSources \[Rule] {{{1, 0, 1}, GrayLevel[ .6]}, {{1, 1, 1}, 
              GrayLevel[ .5]}, {{0, 1, 1}, GrayLevel[ .3]}}, 
        Boxed \[Rule] False, Axes \[Rule] None, ImageSize -> 800, 
        Lighting \[Rule] True]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Animating Light Sources", "Section"],

Cell["\<\
Here, we transform the colors from flat \"glow\" colors to lit surface colors \
that respond to lighting.  Also, we construct a table of frames with a \
varying light source.  The effect is similar to a sunrise-to-sunset \
animation.\
\>", "Text"],

Cell[BoxData[
    \(\(cfgraphanim = 
        Table[Show[msha, 
            LightSources \[Rule] {{{\(-2\)\ Cos[t], 2\ Sin[t],  .5}, White}}, 
            Boxed \[Rule] False, BoxRatios \[Rule] {1, 1,  .4}, 
            ImageSize \[Rule] 500, Background -> Black], {t, 
            0, \[Pi],  .1}];\)\)], "Input"],

Cell[BoxData[
    \(Export["\<sthelens-lights.gif\>", cfgraphanim, "\<GIF\>", 
      ConversionOptions -> {"\<Loop\>" -> True}]\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowSize->{1051, 750},
WindowMargins->{{43, Automatic}, {Automatic, 18}},
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 49, 0, 51, "Subtitle"],
Cell[1828, 55, 46, 0, 30, "Subsubtitle"],
Cell[1877, 57, 183, 4, 30, "Input"],
Cell[2063, 63, 95, 2, 33, "Text"],
Cell[2161, 67, 89, 1, 30, "Input"],
Cell[2253, 70, 49, 1, 30, "Input"],
Cell[2305, 73, 75, 0, 33, "Text"],
Cell[2383, 75, 54, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2462, 80, 42, 0, 73, "Section"],
Cell[2507, 82, 239, 4, 52, "Text"],
Cell[2749, 88, 65, 0, 33, "Text"],
Cell[2817, 90, 74, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2916, 95, 44, 0, 38, "Subsection"],
Cell[2963, 97, 63, 0, 33, "Text"],
Cell[3029, 99, 332, 6, 50, "Input"],
Cell[3364, 107, 183, 4, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3584, 116, 51, 0, 38, "Subsection"],
Cell[3638, 118, 125, 3, 30, "Input"],
Cell[3766, 123, 96, 2, 33, "Text"],
Cell[3865, 127, 248, 4, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4150, 136, 46, 0, 38, "Subsection"],
Cell[4199, 138, 357, 6, 52, "Text"],
Cell[4559, 146, 148, 3, 30, "Input"],
Cell[4710, 151, 148, 3, 30, "Input"],
Cell[4861, 156, 148, 3, 30, "Input"],
Cell[5012, 161, 219, 4, 33, "Text"],
Cell[5234, 167, 150, 2, 30, "Input"],
Cell[5387, 171, 87, 2, 33, "Text"],
Cell[5477, 175, 223, 5, 50, "Input"],
Cell[5703, 182, 70, 0, 33, "Text"],
Cell[5776, 184, 293, 6, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6106, 195, 48, 0, 38, "Subsection"],
Cell[6157, 197, 93, 2, 33, "Text"],
Cell[6253, 201, 188, 4, 50, "Input"],
Cell[6444, 207, 108, 3, 33, "Text"],
Cell[6555, 212, 132, 2, 50, "Input"],
Cell[6690, 216, 112, 3, 33, "Text"],
Cell[6805, 221, 242, 5, 50, "Input"],
Cell[7050, 228, 210, 4, 33, "Text"],
Cell[7263, 234, 259, 5, 30, "Input"],
Cell[7525, 241, 69, 0, 33, "Text"],
Cell[7597, 243, 416, 8, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8062, 257, 42, 0, 73, "Section"],
Cell[8107, 259, 257, 5, 52, "Text"],
Cell[8367, 266, 312, 6, 50, "Input"],
Cell[8682, 274, 140, 2, 30, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

